@@ -95,8 +95,9 @@ class WatchTowerHandler(logging.Handler):
         self.url = '{protocol}://{host}/api/beams/{beam_id}'.format(protocol=self.protocol,
                                                                     host=self.host,
                                                                     beam_id=self.beam_id)
-        self.fallback_url = '{protocol}://{host}'.format(protocol=self.protocol,
-                                                         host=self.fallback_host)
+        self.fallback_url = '{protocol}://{host}/api/beams/{beam_id}'.format(protocol=self.protocol,
+                                                                             host=self.fallback_host,
+                                                                             beam_id=self.beam_id)
 
 
         # Keep ahead depends on queue size, so cannot be 0
